@@ -23,35 +23,16 @@
 #define _NETWORK_H_
 
 #include <config.h>
+
+#include "drivel_request.h"
 #include "drivel.h"
 
-typedef struct _ThreadData ThreadData;
-typedef struct _HTTPMem HTTPMem;
-
-struct _HTTPMem
-{
-	gchar *data;
-	guint len;
-};
-
-struct _ThreadData
-{
-	DrivelClient *dc;
-	gchar *post_data;
-	DrivelRequestType type;
-	GIOChannel *channel;
-};
-
-gboolean
-lj_http_reslv_name(DrivelClient *dc);
-
+/* add a network request to the queue for processing */
 void
-lj_send_request (DrivelClient *dc, const gchar *data, DrivelRequestType type);
+net_enqueue_request (DrivelClient *dc, DrivelRequest *dr);
 
-gboolean
-lj_network_loop (gpointer data);
+/* start the network thread */
+gint
+net_start_thread (DrivelClient *dc);
 
-gchar *
-lj_format_string (const gchar *string);
-
-#endif
+#endif /* _NETWORK_H_ */
